fig811 <- function(post=F)
{
 if(post)
  {#ps.options (colors=ps.colors.rgb[c("blue", "magenta", "cyan",
   #"green", "MediumBlue", "red", "black", "yellow", "blue"),])
    postscript("Fig811.ps", width=4.4, height=6.6, horizontal=F, pointsize=8)
  }
 else {if(dev.cur()==1) motif(); par(ask=T)}
 
 par(mfrow = c(3,1), mar=c(5,3,3,1)+0.1)
 par(mex=0.5,csi=0.11)

 
 SP500 <- matrix(scan("../datasets/SP500",skip=15),ncol=5,byrow=T)
 SP500 <- rev(SP500[1:2529,5])            #closing prices from Jan 2,90
 SP500 <- log(as.numeric(SP500))
 

 ###########  one period return from Jan. 3, 1990   #############
 r1 <- diff(SP500)^2
 lambda <- 0.97
 xlam <- r1*(1-lambda)
 xlam[1] <- r1[1]
 vol1 <- filter(xlam, filter = lambda, method = "rec")
 vol1 <- as.vector(25*vol1)         #converting one-day volatility
                                    #into 25 day volatility

 ########## 25-day return from Jan. 27, 1990   ###############

 r25 <- SP500[26:length(SP500)] - SP500[1:(length(SP500)-25)]
 r25 <- r25^2
 xlam <- r25*(1-lambda)
 xlam[1] <- r25[1]
 vol25 <- filter(xlam, filter = lambda, method = "rec")
 vol25 <- as.vector(vol25)

 ########## Fitting:  predicting future 25-day volatility from
 ########## vol25 and vol1, starting from Jan. 2, 1991
 ########## (254 trading-days away Jan. 2, 1990), to April 30, 1996
 ########## (1500 trading away from Jan. 2,90)
 ###################################################################


 vola1 <- vol1[252:1474]         #observed one-day volatility,
 vola25<- vol25[253:1475]        #unobserved smoothed 25-day volatility

 plot(vola1, vola25, xlab="(a)")
 coef1 <- l1fit(vola1,vola25)$coef
 abline(coef1); #print(coef1)
 coef2 <- lsfit(vola1,vola25)$coef
 abline(coef2,lty=2); #print(coef2)
 title("Observed volatility versus unobserved 25-day volatility")
 legend(0.0005,0.008,c(paste("L1, slope",     round(coef1,3)[2]),
                       paste("L1, intercept", round(coef1,5)[1]),
                       paste("L2, slope",     round(coef2,3)[2]),
                       paste("L2, intercept", round(coef2,5)[1])),
	               lty=c(1,1,2,2))


 y <- r25[253:1475]                 #future 25-day squared return
 vola25 <- vol25[(253-25):(1475-25)] #observed 25-day volatility
 
 plot(vola1, y, xlab ="(b)")
 coef1 <- l1fit(vola1,y)$coef
 abline(coef1); #print(coef1)
 coef2 <- lsfit(vola1,y)$coef
 abline(coef2,lty=2); #print(coef2)
 legend(0.0005,0.025,c(paste("L1, slope",     round(coef1,3)[2]),
                       paste("L1, intercept", round(coef1,5)[1]),
                       paste("L2, slope",     round(coef2,3)[2]),
                       paste("L2, intercept", round(coef2,5)[1])),
	               lty=c(1,1,2,2))
 title("Observed 1-day volatility versus future square returns")

 plot(vola25, y, xlab ="(c)")
 coef1 <- l1fit(vola25,y)$coef
 abline(coef1); #print(coef1)
 coef2 <- lsfit(vola25,y)$coef
 abline(coef2,lty=2); #print(coef2)
 legend(0.004,0.025,c(paste("L1, slope",     round(coef1,3)[2]),
                       paste("L1, intercept", round(coef1,5)[1]),
                       paste("L2, slope",     round(coef2,3)[2]),
                       paste("L2, intercept", round(coef2,5)[1])),
	               lty=c(1,1,2,2))
 title("Observed 25-day volatility versus future square returns")
 lsfit(cbind(vola1,vola25),y)
}
